#!/usr/bin/env python

import fnmatch
import os
import sys

from lib.util import execute

IGNORE_FILES = [
  os.path.join('browser', 'atom_application_mac.h'),
  os.path.join('browser', 'atom_application_delegate_mac.h'),
  os.path.join('browser', 'native_window_mac.h'),
  os.path.join('browser', 'resources', 'win', 'resource.h'),
  os.path.join('browser', 'ui', 'cocoa', 'event_processing_window.h'),
  os.path.join('browser', 'ui', 'cocoa', 'atom_menu_controller.h'),
  os.path.join('browser', 'ui', 'cocoa', 'nsalert_synchronous_sheet.h'),
  os.path.join('browser', 'ui', 'gtk', 'gtk_custom_menu.cc'),
  os.path.join('browser', 'ui', 'gtk', 'gtk_custom_menu_item.cc'),
  os.path.join('common', 'api', 'api_messages.cc'),
  os.path.join('common', 'api', 'api_messages.h'),
  os.path.join('common', 'atom_version.h'),
  os.path.join('common', 'swap_or_assign.h'),
]

SOURCE_ROOT = os.path.dirname(os.path.dirname(__file__))


def main():
  os.chdir(SOURCE_ROOT)
  files = list_files(['app', 'browser', 'common', 'renderer'],
                     ['*.cc', '*.h'])
  call_cpplint(list(set(files) - set(IGNORE_FILES)))


def list_files(directories, filters):
  matches = []
  for directory in directories:
    for root, _, filenames, in os.walk(directory):
      for f in filters:
        for filename in fnmatch.filter(filenames, f):
          matches.append(os.path.join(root, filename))
  return matches


def call_cpplint(files):
  cpplint = os.path.join(SOURCE_ROOT, 'vendor', 'depot_tools', 'cpplint.py')
  rules = '--filter=-build/header_guard,-build/include_what_you_use'
  execute([sys.executable, cpplint, rules] + files)


if __name__ == '__main__':
  sys.exit(main())
